# AUTOGENERATED! DO NOT EDIT! File to edit: 03_cli.ipynb (unless otherwise specified).

__all__ = ['dfset_writer', 'hecss_sampler']

# Cell
#export
import click
from pathlib import Path
import os
import ase
from ase.calculators.vasp import Vasp
from ase import units as un
from .core import *

# Cell
def dfset_writer(s, sl, workdir=''):
    '''
    Just write samples to the DFSET.dat file in the workdir directory.
    '''
    wd = Path(workdir)
    write_dfset(f'{wd.joinpath("DFSET.dat")}', s)
    # Important! Return False to keep iteration going
    return False

# Cell
def hecss_sampler(fname='CONTCAR', workdir='WORK', label='hecss',
                  T=300, calc='VASP', dfset=True, N=10, command='./run-calc'):
    '''
    Run HECSS sampler on the structure in the directory.
    fname - Basic structure file. Any type recognized by ASE is accepted.
    '''
    print(f'Running HECSS on {fname}\n',
          f'Temperature:    {T}K\n',
          f'Work directory: {workdir}\n',
          f'Calculator:     {calc}.')

    src_path = Path(fname)

    print(src_path.parent, src_path.name)

    if calc=="VASP":
        calculator = Vasp(label=label, directory=src_path.parent, restart=True)
        cryst = ase.Atoms(calculator.atoms)
        cryst.set_calculator(calculator)
        calculator.set(directory=workdir)
        command = Path(command)
        calculator.set(command=f'{command.absolute()} {label}')
    sentinel = None
    if dfset :
        sentinel = dfset_writer
    sampler = HECSS(cryst, calculator, T, directory=workdir)
    samples = sampler.generate(N, sentinel=sentinel, workdir=workdir)
    return samples

# Cell
@click.command()
@click.argument('fname', default='CONTCAR', type=click.Path(exists=True))
@click.option('-w', '--workdir', default="WORK", type=click.Path(exists=True), help="Work directory")
@click.option('-l', '--label', default="hecss", help="Label for the calculations.")
@click.option('-T', '--temp', default=300, help="Target temperature in Kelvin.")
@click.option('-C', '--calc', default="VASP", type=str,
              help="ASE calculator to be used for the job.\n" + "Supported calculators: VASP (default)")
@click.option('--dfset/--no-dfest', default=True, help='Write DFSET file for ALAMODE')
@click.option('-N', '--nsamples', default=10, type=str, help="Number of samples to be generated")
@click.option('-c', '--command', default='/run-calc', help="Command to run calculator")
def _hecss_sampler(fname, workdir, label, temp, calc, dfset, nsamples, command):
    '''
    Run HECSS sampler on the structure in the directory.
    fname - Basic structure file. Any type recognized by ASE is accepted.
    '''
    return hecss_sampler(fname=fname,
                         workdir=workdir,
                         label=label,
                         T=temp,
                         calc=calc,
                         dfset=dfset,
                         N=nsamples,
                         command=command)